<?php
/*
Plugin Name: Instant Messaging Button
Plugin URI: https://bewiser.co.il/wordpress/instant-messaging-button
Description: Adds a WhatsApp contact button to your WordPress site.
Version: 1.0
Requires PHP: 5.6
Author: Michael Dahan
Author URI: https://bewiser.co.il
License: GPLv3
License URI: http://www.gnu.org/licenses/gpl.html
Text Domain: instant-messaging-button
Domain Path: /languages
*/
/*
Instant Messaging Button is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or
any later version.

Instant Messaging Button is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Instant Messaging Button. If not, see http://www.gnu.org/licenses/gpl.html.
*/

defined ( 'ABSPATH' ) or die();
define( 'PREFIX_ASSETS_URL', plugins_url( '/public', __FILE__ ) );
define( 'INSMES_PLUGIN_NAME', plugin_basename( __FILE__ ) ); 

/**
 * Load text domain for translation
 * 
 * @since 1.0.0
 */
function  insmes_button_load_textdomain() {

    load_plugin_textdomain( 'instant-messaging-button', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );

}
add_action( 'plugins_loaded', 'insmes_button_load_textdomain' );

/**
 * Add link to admin settings page.
 * 
 * @since 1.0.0
 * 
 * @param array $links array of links.
 * 
 * @return array array of links.
 */
function settings_link( $links ) {

    // $docs_link = '<a href="admin.php?page=wiser_slider_settings&tab=information">Docs</a>';
    $settings_link = '<a href="admin.php?page=instant-messaging-button-settings">Settings</a>';

    array_push( $links, $settings_link );
    
    return $links;

}
add_filter( 'plugin_action_links_' . INSMES_PLUGIN_NAME, 'settings_link' );

/**
 * Add WhatsApp button to the footer
 * 
 * @since 1.0.0
 */
function insmes_add_whatsapp_button() {

    $button_activate     = get_option( 'insmes_activation_button' );
    $phone_number        = get_option( 'insmes_phone_number' );
    $custom_message      = get_option( 'insmes_custom_message' );
    $button_position     = get_option( 'insmes_button_position' );
    $button_margin       = get_option( 'insmes_button_margin' );
    $button_bottom       = get_option( 'insmes_button_bottom' );
    $button_custom_image = get_option( 'insmes_button_custom_image' );
    $custom_image_size   = get_option( 'insmes_custom_image_size' );

    // Set default values if not set
    if ( empty( $button_position ) ) {
        $button_position = 'right';
    }
    if ( empty( $button_margin ) ) {
        $button_margin = '10';
    }
    if ( empty( $button_bottom ) ) {
        $button_bottom = '10';
    }
    if ( empty( $custom_image_size ) ) {
        $custom_image_size = '50';
    }
    if ( empty( $button_activate ) ) {
        $button_activate = 'deactivate';
    }

    // WhatsApp button markup
    $whatsapp_button = '';

    // add text key to url, if any
    !empty( $custom_message ) ? $custom_message = '&text=' . urlencode( $custom_message ) : '';

    /**
     * Build WhatsApp button
     */
    if ( !empty( $button_custom_image ) ) {
        $whatsapp_button = '<a href="https://wa.me/send?phone=' . sanitize_text_field( $phone_number .  $custom_message ) . '" target="_blank" class="whatsapp-button" title="Whatsapp Connection">';
        $whatsapp_button .= '<img src="' . esc_url( $button_custom_image ) . '" alt="' . esc_attr( 'WhatsApp', 'instant-messaging-button' ) . '" width="' . esc_attr( $custom_image_size ) . '" height="' . esc_attr( $custom_image_size ) . '">';
        $whatsapp_button .= '</a>';
    } else {
        // Default to predefined image
        $whatsapp_button = '<a href="https://wa.me/send?phone=' . sanitize_text_field( $phone_number . $custom_message ) . '" target="_blank" class="whatsapp-button" title="Message us to Whatsapp">';
        $whatsapp_button .= '<img src="' . PREFIX_ASSETS_URL . '/images/whatsapp-logo.webp' . '" alt="' . esc_attr( 'WhatsApp', 'instant-messaging-button' ) . '" width="' . esc_attr( $custom_image_size ) . '" height="' . esc_attr( $custom_image_size ) . '">';
        $whatsapp_button .= '</a>';
    }

    // Style WhatsApp button
    $button_style = '<style>';
    $button_style .= '.whatsapp-button {';
    $button_style .= 'position: fixed;';
    $button_style .= $button_position . ': ' . $button_margin . 'px;';
    $button_style .= 'bottom: ' . $button_bottom . 'px;';
    $button_style .= 'z-index: 9999;';
    $button_style .= '}';
    $button_style .= '</style>';

    // Allow kses
    $btn_stl_kss = array(
        'style' => array(),
    );
    $btn_kss = array( 
        'a' => array(
           'href'   => array(),
           'title'  => array(),
           'target' => array(),
           'class'  => array()
        ),
        'img' => array(
            'src'    => array(),
            'alt'    => array(),
            'width'  => array(),
            'height' => array()

        ) 
    );
    
    /**
     * Output WhatsApp button and style
     */
    if ( $button_activate == 'activate' &&  !empty( $phone_number ) ) {
        
        echo wp_kses( $button_style, $btn_stl_kss );
        echo wp_kses( $whatsapp_button, $btn_kss );

    }
}
add_action( 'wp_footer', 'insmes_add_whatsapp_button' );

/**
 * Add settings page
 * 
 * @since 1.0.0
 */    
function insmes_contact_button_settings_page() {
    add_options_page(
        __( 'Instant Messaging - WhatsApp Button', 'instant-messaging-button' ),
        __( 'Instant Messaging', 'instant-messaging-button' ),
        'manage_options',
        'instant-messaging-button-settings',
        'insmes_button_settings_content'
    );
}
add_action('admin_menu', 'insmes_contact_button_settings_page');

/**
 * Callback function to display settings content
 * 
 * @since 1.0.0
 */
function insmes_button_settings_content() {

    // initialize WP_Locale class
    $wp_locale = new WP_Locale();
    // check if is rtl - return bool
    $wp_locale = is_rtl();
    // set direction to left if is_rtl true, otherwise right
    $wp_locale == '1' ? $wp_locale = esc_html( 'left' ) : $wp_locale = esc_html( 'right' ); 

    ?>
    <div class="wrap">
        <h2><?php esc_html_e( 'Instant Messaging - WhatsApp Button', 'instant-messaging-button' ); ?></h2>
        <form method="post" action="options.php">
            <?php settings_fields( 'whatsapp_contact_button_settings_group' ); ?>
            <table class="form-table">
                <input type="hidden" name="insmes_whatsapp_button_nonce" value="<?php echo esc_attr( wp_create_nonce( 'insmes_whatsapp_button_nonce' ) ); ?>" class="hidden">
                <tr valign="top">
                    <th scope="row"><?php esc_html_e( 'Activate Button', 'instant-messaging-button' ) ?> <span class="tooltip <?php echo $wp_locale; ?>">? <span class="tooltiptext"><?php esc_html_e( 'Activate/Deactivate botton', 'instant-messaging-button' ); ?></span></span></th>
                    <td>
                    <select name="insmes_activation_button">
                            <option value="activate" <?php selected( get_option( 'insmes_activation_button' ), 'activate' ); ?>><?php esc_html_e( 'Activate', 'instant-messaging-button' ); ?></option>
                            <option value="deactivate" <?php selected( get_option( 'insmes_activation_button' ), 'deactivate' ); ?>><?php esc_html_e( 'Deactivate', 'instant-messaging-button' ); ?></option>
                        </select>
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row"><?php esc_html_e( 'WhatsApp Phone Number:', 'instant-messaging-button' ) ?> <span class="tooltip <?php echo $wp_locale; ?>">?<span class="tooltiptext"><?php esc_html_e( 'Please include the country code', 'instant-messaging-button' ); ?></span></span></th>
                    <td><input type="tel" autocorrect="on" pattern="[0-9]*" maxlength="14" name="insmes_phone_number" value="<?php echo esc_attr( get_option( 'insmes_phone_number' ) ); ?>" /></td>
                </tr>
                <tr valign="top">
                    <th scope="row"><?php esc_html_e( 'Custom Message:', 'instant-messaging-button' ); ?> <span class="tooltip <?php echo $wp_locale; ?>">?<span class="tooltiptext"><?php esc_html_e( 'Set an opening message for WhatsApp', 'instant-messaging-button' ); ?></span></span></th>
                    <td><input type="text" name="insmes_custom_message" value="<?php echo esc_attr( get_option( 'insmes_custom_message' ) ); ?>" title="<?php esc_html_e( 'Please enter a valid phone number', 'instant-messaging-button' ); ?>" /></td>
                </tr>
                <tr valign="top">
                    <th scope="row"><?php esc_html_e( 'Button Position:', 'instant-messaging-button' ); ?> <span class="tooltip <?php echo $wp_locale; ?>">?<span class="tooltiptext"><?php esc_html_e( 'Choose your preffered side', 'instant-messaging-button' ); ?></span></span></th>
                    <td>
                        <select name="insmes_button_position">
                            <option value="left" <?php selected( get_option( 'insmes_button_position' ), 'left' ); ?>><?php esc_html_e( 'Left', 'instant-messaging-button' ); ?></option>
                            <option value="right" <?php selected( get_option( 'insmes_button_position' ), 'right' ); ?>><?php esc_html_e( 'Right', 'instant-messaging-button' ); ?></option>
                        </select>
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row"><?php esc_html_e( 'Sides Margin (px):', 'instant-messaging-button' ); ?> <span class="tooltip <?php echo $wp_locale; ?>">?<span class="tooltiptext"><?php esc_html_e( 'Min: 1px, Max: 50px, default: 10px', 'instant-messaging-button' ); ?></span></span></th>
                    <td><input type="number" min="1" max="50" name="insmes_button_margin" value="<?php echo esc_attr( get_option('insmes_button_margin' ) ) ? esc_attr( get_option('insmes_button_margin' ) ) : 10; ?>" /></td>
                </tr>
                <tr valign="top">
                    <th scope="row"><?php esc_html_e( 'Bottom Margin (px):', 'instant-messaging-button' ); ?> <span class="tooltip <?php echo $wp_locale; ?>">?<span class="tooltiptext"><?php esc_html_e( 'Min: 1px, Max: 50px, default: 10px', 'instant-messaging-button' ); ?></span></span></th>
                    <td><input type="number" min="1" max="50" name="insmes_button_bottom" value="<?php echo esc_attr( get_option( 'insmes_button_bottom' ) ) ? esc_attr( get_option( 'insmes_button_bottom' ) ) : 10; ?>" /></td>
                </tr>
                <tr valign="top">
                    <th scope="row"><?php esc_html_e( 'Custom Image:', 'instant-messaging-button' ); ?> <span class="tooltip <?php echo $wp_locale; ?>">?<span class="tooltiptext"><?php esc_html_e( 'Upload your own Image', 'instant-messaging-button' ); ?></span></span></th>
                    <td>
                        <?php $custom_image = get_option('insmes_button_custom_image'); ?>
                        <input type="hidden" id="insmes_button_custom_image" name="insmes_button_custom_image" value="<?php echo esc_attr( $custom_image ); ?>">
                        <input type="button" id="upload_image_button" class="button-primary" value="<?php esc_html_e( 'Upload Image', 'instant-messaging-button' ); ?>" />
                        <input type="button" id="remove_image_button" class="button-secondary" value="<?php esc_html_e( 'Remove Image', 'instant-messaging-button' ); ?>" <?php if (empty($custom_image)) echo 'style="display: none;"'; ?> />
                        <div id="insmes_button_custom_image_preview">
                            <?php if ( $custom_image ) { ?>
                                <img src="<?php echo esc_url( $custom_image ); ?>" />
                            <?php } else { ?>
                                <img src="<?php echo esc_url( PREFIX_ASSETS_URL . '/images/whatsapp-logo.webp' ); ?>" />
                                <small><?php esc_html_e( 'Default Image Uploaded', 'instant-messaging-button' ); ?></small>
                            <?php } ?>
                        </div>
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row"><?php esc_html_e( 'Image Size (width in px):', 'instant-messaging-button' ); ?> <span class="tooltip <?php echo $wp_locale; ?>">?<span class="tooltiptext"><?php esc_html_e( 'Min: 40px, Max: 300px, default: 50px', 'instant-messaging-button' ); ?></span></span></th>
                    <td><input type="number" min="40" max="300" name="insmes_custom_image_size" value="<?php echo esc_attr( get_option('insmes_custom_image_size' ) ) ? esc_attr( get_option('insmes_custom_image_size' ) ) : 50 ?>" /></td>
                </tr>
            </table>
            
            <style>
                    .tooltip {
                        position: relative;
                        display: block;
                        cursor: pointer;
                        background: #555;
                        border-radius: 10px;
                        font-size: 11px;
                        color: #fff;
                    }
                    .left {
                        padding: 0 4px;
                        margin: 0 0 0 -12px;
                        float: left;
                    }
                     .right {
                        padding: 0 5px 1px;
                        margin: 0 -12px 0 0;
                        float: right;
                    }
                    .tooltip .tooltiptext {
                        visibility: hidden;
                        width: 120px;
                        background-color: #555;
                        color: #fff;
                        text-align: center;
                        border-radius: 6px;
                        padding: 5px;
                        position: absolute;
                        z-index: 1;
                        bottom: 125%;
                        left: 50%;
                        margin-left: -60px;
                    }
                    .tooltip:hover .tooltiptext {
                        visibility: visible;
                    }
                    #insmes_button_custom_image_preview img {
                        display: block;
                        margin: auto;
                        max-width: 180px;
                        
                    }
                    #insmes_button_custom_image_preview {
                        box-shadow: 0 0px 2px #bbb;
                        background-color: white;
                        max-width: 180px;
                        padding: 6px;
                        margin-top: 15px;
                        text-align: center;
                        
                    }
                    @media screen AND (max-width: 767px) {
                        .tooltip {
                            float: none;
                            display: inline-block;
                        }
                    }
                </style>
            <?php submit_button(); ?>
        </form>
        <div class="info">
            <h3><?php esc_html_e( 'Information:', 'instant-messaging-button' ); ?></h3>
            <p><?php printf( __( 'Need help with the plugin? Reach us at our <a href="%s" target="_BLANK">website</a>', 'instant-messaging-button' ), 'https://bewiser.co.il' ) ?></p>
        
        </div>
    </div>
    <script>
        jQuery(document).ready(function($){
            $('#upload_image_button').click(function() {
                var send_attachment_bkp = wp.media.editor.send.attachment;
                wp.media.editor.send.attachment = function(props, attachment) {
                    $('#insmes_button_custom_image').val(attachment.url);
                    $('#insmes_button_custom_image_preview img').attr('src', attachment.url);
                    $('#remove_image_button').show();
                    wp.media.editor.send.attachment = send_attachment_bkp;
                }
                wp.media.editor.open();
                return false;
            });

            $('#remove_image_button').click(function() {
                $('#insmes_button_custom_image').val('');
                $('#insmes_button_custom_image_preview img').attr('src', '');
                $(this).hide();
            });
        });
    </script>
    <?php
}

/**
 * Register and sanitize settings
 * 
 * @since 1.0.0
 */
if ( ! function_exists( 'insmes_contact_button_settings_init' ) ) {

    function insmes_contact_button_settings_init() {
        
        if ( isset( $_POST[ 'insmes_whatsapp_button_nonce' ] ) ) {
            
            if ( ! wp_verify_nonce( $_POST[ 'insmes_whatsapp_button_nonce' ], 'insmes_whatsapp_button_nonce' ) ) {
                
                return;
                
            }
        }
        
        if (current_user_can('manage_options')) {
            
            register_setting( 'whatsapp_contact_button_settings_group', 'insmes_button_margin', 'absint' ); 
            register_setting( 'whatsapp_contact_button_settings_group', 'insmes_button_bottom', 'absint' );
            register_setting( 'whatsapp_contact_button_settings_group', 'insmes_custom_image_size', 'absint' );
            register_setting( 'whatsapp_contact_button_settings_group', 'insmes_button_custom_image', 'esc_url_raw');
            register_setting( 'whatsapp_contact_button_settings_group', 'insmes_phone_number', 'sanitize_text_field' );
            register_setting( 'whatsapp_contact_button_settings_group', 'insmes_custom_message', 'sanitize_text_field' );
            register_setting( 'whatsapp_contact_button_settings_group', 'insmes_button_position', 'sanitize_text_field' );
            register_setting( 'whatsapp_contact_button_settings_group', 'insmes_activation_button', 'sanitize_text_field' );
        }
    }
}
add_action( 'admin_init', 'insmes_contact_button_settings_init' );

// Register deactivation hook
register_deactivation_hook( __FILE__, 'insmes_contact_button_deactivate' );

/**
 * Function to run on deactivation
 * 
 * @since 1.0.0
 */
function insmes_contact_button_deactivate() {

    /**
     * Capabilities guard
     */
    if ( ! current_user_can( 'manage_options' ) ) {
        return;
    }
     
    // Delete plugin options
    // delete_option( 'insmes_phone_number' );
    // delete_option( 'insmes_button_margin' );
    // delete_option( 'insmes_button_bottom' );
    // delete_option( 'insmes_custom_message' );
    // delete_option( 'insmes_button_position' );
    // delete_option( 'insmes_activation_button' );
    // delete_option( 'insmes_custom_image_size' );
    // delete_option( 'insmes_button_custom_image' );
}

// Register uninstall hook
register_uninstall_hook( __FILE__, 'insmes_contact_button_uninstall' );

/**
 * Function to run on uninstallation
 * 
 * @since 1.0.0
 */
function insmes_contact_button_uninstall() {

    /**
     * Capabilities guard
     */
    if ( ! current_user_can( 'manage_options' ) ) {
        return;
    }

    // Delete plugin options
    delete_option( 'insmes_phone_number' );
    delete_option( 'insmes_button_margin' );
    delete_option( 'insmes_button_bottom' );
    delete_option( 'insmes_custom_message' );
    delete_option( 'insmes_button_position' );
    delete_option( 'insmes_activation_button' );
    delete_option( 'insmes_custom_image_size' );
    delete_option( 'insmes_button_custom_image' );
}
